@@ -251,6 +251,7 @@ class Client:
 
         Example output:
 
+        ```
         {
             "id": 3,
             "title": "paintings",
@@ -264,6 +265,7 @@ class Client:
             "public_access": false,
             "tags": [],
         }
+        ```
         """
         return self.__call("add_collection", [title, parent_id])
 
@@ -278,6 +280,7 @@ class Client:
 
         Example output:
 
+        ```
         [
             {
                 "id": 1,
@@ -319,6 +322,7 @@ class Client:
                 "tags": [],
             },
         ]
+        ```
         """
         return self.__call("add_collection_from_path", [path])
 
@@ -396,15 +400,17 @@ class Client:
 
         Example input:
 
+        ```
         [
             {"property": "title", "term": "contains", "value": "cherbourg"},
-            {"meta": 123, "term": "is", "value": "35mm"}
+            {"meta": 123, "term": "is", "value": "35mm"},
+            {"tags": ["PAINTINGS", "PHOTOS"]}
         ]
+        ```
 
         Example output:
 
-        Example output:
-
+        ```
         {
             "collections": [],
             "resources": [
@@ -420,6 +426,7 @@ class Client:
                 }
             ]
         }
+        ```
         """
         return self.__call("advanced_search", [search_terms])
 
@@ -429,7 +436,13 @@ class Client:
 
         Example output:
 
-        ["is", "contains", "does_not_contain"]
+        ```
+        [
+            "is",
+            "contains",
+            "does_not_contain"
+        ]
+        ```
         """
         return self.__call("advanced_search_terms", [])
 
@@ -443,6 +456,7 @@ class Client:
 
         Example output:
 
+        ```
         [
             {
                 "id": 1,
@@ -484,6 +498,7 @@ class Client:
                 "tags": [],
             },
         ]
+        ```
         """
         return self.__call("ancestors_from_collection", [collection_id, include_self])
 
@@ -493,6 +508,7 @@ class Client:
 
         Example output:
 
+        ```
         [
             {
                 "id": 1,
@@ -534,6 +550,7 @@ class Client:
                 "tags": [],
             },
         ]
+        ```
         """
         return self.__call("ancestors_from_resource", [resource_id])
 
@@ -555,6 +572,7 @@ class Client:
 
         Example output:
 
+        ```
         {
             "id": 2,
             "title": "art works",
@@ -568,6 +586,7 @@ class Client:
             "public_access": False,
             "tags": [],
         }
+        ```
         """
         return self.__call("collection", [collection_id])
 
@@ -581,6 +600,7 @@ class Client:
 
         Example output:
 
+        ```
         [
             {
                 "id": 2,
@@ -596,16 +616,18 @@ class Client:
                 "tags": [],
             }
         ]
+        ```
         """
         return self.__call("collections", [parent_id, recusive])
 
-    def delete_collection(self, collection_id: int) -> bool:
+    def delete_collection(self, collection_id: int, recursive: bool = False) -> bool:
         """
         Delete collection given its id.
 
-        Collection MUST be empty of any content (no children collections and no resources).
+        Collection MUST be empty of any content (no children collections and no resources),
+        unless the 'recursive' parameter is set to True.
         """
-        return self.__call("delete_collection", [collection_id])
+        return self.__call("delete_collection", [collection_id, recursive])
 
     def delete_file(self, file_id: int) -> bool:
         """
@@ -637,6 +659,7 @@ class Client:
 
         Example output:
 
+        ```
         {
             "id": 2,
             "title": "ICC_Profile:GrayTRC",
@@ -645,6 +668,7 @@ class Client:
             "rank": 1,
             "owner": "john",
         }
+        ```
         """
         return self.__call("metadata", [metadata_id])
 
@@ -656,6 +680,7 @@ class Client:
 
         Example output:
 
+        ```
         [
             {
                 "id": 1,
@@ -674,6 +699,7 @@ class Client:
                 "owner": "john",
             }
         ]
+        ```
         """
         return self.__call("metadatas", [metadata_set_id])
 
@@ -684,10 +710,12 @@ class Client:
 
         Example output:
 
+        ```
         [
             {"id": 1, "title": "exif metas", "owner": "john", "metas_count": 23},
             {"id": 2, "title": "dublin core", "owner": "john", "metas_count": 17}
         ]
+        ```
         """
         return self.__call("metadatasets", [])
 
@@ -697,10 +725,12 @@ class Client:
 
         Example output:
 
+        ```
         [
             {"id": 1, "title": "text"},
             {"id": 2, "title": "numeric"},
         ]
+        ```
         """
         return self.__call("metadatatypes", [])
 
@@ -729,7 +759,9 @@ class Client:
 
         Example output:
 
+        ```
         pong john
+        ```
         """
         return self.__call("ping", [])
 
@@ -827,6 +859,7 @@ class Client:
 
         Example output (file resource):
 
+        ```
         {
             "id": 1,
             "title": "letter",
@@ -837,6 +870,7 @@ class Client:
             "urls": [],
             "tags": [],
         }
+        ```
         """
         return self.__call("resource", [resource_id])
 
@@ -852,6 +886,7 @@ class Client:
 
         Example output (file resource):
 
+        ```
         [
             {
                 "id": 1,
@@ -864,6 +899,7 @@ class Client:
                 "tags": [],
             }
         ]
+        ```
         """
         return self.__call("resources", [collection_id, include_metas])
 
@@ -873,12 +909,14 @@ class Client:
 
         Example output:
 
+        ```
         {
             "id": 1,
             "uid": "PAINTINGS",
             "label": "peintures",
             "ark": null,
         }
+        ```
         """
         return self.__call("set_tag", [uid, label, ark])
 
@@ -888,6 +926,7 @@ class Client:
 
         Example output:
 
+        ```
         {
             "collections": [
                 {
@@ -917,6 +956,7 @@ class Client:
                 }
             ]
         }
+        ```
         """
         return self.__call("simple_search", [query])
 
@@ -926,6 +966,7 @@ class Client:
 
         Example output:
 
+        ```
         [
             {
             "mime": "image/jpeg",
@@ -933,6 +974,7 @@ class Client:
             "iiif_support": true,
             }
         ]
+        ```
         """
         return self.__call("supported_file_types", [])
 
@@ -942,6 +984,7 @@ class Client:
 
         Example output:
 
+        ```
         [
             {
             "id": 1,
@@ -956,6 +999,7 @@ class Client:
             "ark": null,
             }
         ]
+        ```
         """
         return self.__call("tags", [])
 
@@ -971,11 +1015,13 @@ class Client:
 
         Example output:
 
+        ```
         {
             "status": "not available",
             "id": null,
             "available_chunks":[]
         }
+        ```
 
         "status" being one of "not available", "available" or "incomplete"
         """
